@@ -7,6 +7,6 @@ app_name = "django_navbar_client"
 urlpatterns = [
     path('api/login_callback/', oauth_callback, name="callback"),
     path('view/logout/', oauth_logout, name="logout"),
-    path('view/login/', oauth_login, name="logout"),
-    path('widget/navbar/', oauth_navbar, name="navbar"),
+    path('view/login/', oauth_login, name="login"),
+    path('api/navbar/', oauth_navbar, name="navbar"),
 ]
